%define mainrel 1
%define snapshot 20200220
%define rel 7

Name:           bear
Epoch:          1
Version:        0.7.0
Release:        %mkrel %{mainrel}.%{snapshot}.%{rel}
Summary:        Game engine and editors dedicated to creating great 2D games
Group:          Development/C++
License:        GPLv3+ and CC-BY-SA 3.0
URL:            https://github.com/j-jorge/bear
Source0:        %{name}-%{snapshot}.tar.xz
Patch1:         bear-boost-placeholders.patch
Patch2:		bear-missing-includes.patch
Patch3:		bear-rpath.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-to-man
BuildRequires:  gettext
BuildRequires:  libclaw-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  wxgtk3.0-devel

%description
The Bear engine is a set of C++ libraries and tools dedicated to creating
great 2D games. It has been used to create Plee the Bear (plee-the-bear),
Andy's Super Great Park (andy-super-great-park) and Tunnel (non packaged).

The engine comes with a set of tools, namely the Bear Factory, intended to
help creating resources for the game. These tools include a level editor,
a character/model editor and an animation editor.

#----------------------------------------------------------------------

%package engine
Summary:        Runtime libraries for games based on the Bear engine
Group:          System/Libraries

%description engine
The Bear engine is a set of C++ libraries and tools dedicated to creating
great 2D games. It has been used to create Plee the Bear (plee-the-bear),
Andy's Super Great Park (andy-super-great-park) and Tunnel (non packaged).

This package contains the runtime libraries used by the games based on
the Bear engine.

%files engine -f %{name}-engine.lang
%doc README.md LICENSE
%dir %{_libdir}/%{name}
%{_libdir}/bear/libbear_audio.so
%{_libdir}/bear/libbear_communication.so
%{_libdir}/bear/libbear_debug.so
%{_libdir}/bear/libbear_engine.so
%{_libdir}/bear/libbear_expr.so
%{_libdir}/bear/libbear_generic_items.so
%{_libdir}/bear/libbear_gui.so
%{_libdir}/bear/libbear_input.so
%{_libdir}/bear/libbear_net.so
%{_libdir}/bear/libbear_text_interface.so
%{_libdir}/bear/libbear_time.so
%{_libdir}/bear/libbear_universe.so
%{_libdir}/bear/libbear_visual.so
%{_datadir}/cmake/%{name}-engine/
%{_mandir}/man6/running-%{name}.6*

#----------------------------------------------------------------------

%package factory
Summary:        Level, animation and model editors for the Bear engine
Group:          Games/Other
Conflicts:      bear-factory < 1.0.8-7

%description factory
This package includes the level editor, animation editor and model editor
of the Bear Engine for Plee the Bear & Andy's Super Great Park.

%files factory -f %{name}-factory.lang
%{_bindir}/bend-image
%{_bindir}/bf*editor
%{_bindir}/image-cutter
%{_libdir}/%{name}/lib%{name}-editor.so
%dir %{_datadir}/%{name}-factory/
%{_datadir}/%{name}-factory/images/
%{_datadir}/%{name}-factory/item-description/
%{_datadir}/applications/bf*editor.desktop
%{_datadir}/applications/desc2img.desktop
%{_iconsdir}/hicolor/*/apps/%{name}-factory.png
%{_mandir}/man1/bf*editor.1*

#----------------------------------------------------------------------

%prep
%setup -qn %{name}-%{snapshot}
%autopatch -p1

%build
%cmake -DBEAR_ENGINE_INSTALL_LIBRARY_DIR=%{_lib}/%{name} \
       -DBEAR_FACTORY_INSTALL_LIBRARY_DIR=%{_lib}/%{name} \
       -DBEAR_USES_FREEDESKTOP=ON \
       -DBEAR_EDITORS_ENABLED=ON
%cmake_build

%install
%cmake_install

%find_lang %{name}-engine
%find_lang %{name}-factory

rm -rf %{buildroot}%{_datadir}/pixmaps


%changelog
* Sat Dec 24 2022 wally <wally> 1:0.7.0-1.20200220.7.mga9
+ Revision: 1926455
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 1:0.7.0-1.20200220.6.mga9
+ Revision: 1867229
- rebuild for boost 1.79.0

* Sun Apr 03 2022 umeabot <umeabot> 1:0.7.0-1.20200220.5.mga9
+ Revision: 1842804
- Mageia 9 Mass Rebuild

* Wed Dec 22 2021 wally <wally> 1:0.7.0-1.20200220.4.mga9
+ Revision: 1763303
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 1:0.7.0-1.20200220.3.mga9
+ Revision: 1762616
- rebuild for boost 1.78.0

* Sat Sep 11 2021 wally <wally> 1:0.7.0-1.20200220.2.mga9
+ Revision: 1745201
- fix RPATH
- add patch to fix missing includes
- rebuild for boost 1.77.0

* Sat May 15 2021 wally <wally> 1:0.7.0-1.20200220.1.mga9
+ Revision: 1723376
- new snapshot 20200220
- switch to wxgtk 3.0
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1:0.7.0-1.20141028.16.mga8
+ Revision: 1666736
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1:0.7.0-1.20141028.15.mga8
+ Revision: 1661978
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 1:0.7.0-1.20141028.14.mga8
+ Revision: 1578307
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 1:0.7.0-1.20141028.13.mga8
+ Revision: 1544583
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1:0.7.0-1.20141028.12.mga8
+ Revision: 1483343
- rebuild for boost 1.72.0
- build with new cmake macros

* Thu Jul 25 2019 wally <wally> 1:0.7.0-1.20141028.11.mga8
+ Revision: 1423882
- add patch to fix build with wxgtk
- drop ld.so.conf.d conf files (as CMAKE_SKIP_RPATH isn't enabled by default anymore)

* Tue Oct 16 2018 wally <wally> 1:0.7.0-1.20141028.10.mga7
+ Revision: 1321010
- rebuild for new boost 1.68.0

* Wed Oct 03 2018 pterjan <pterjan> 1:0.7.0-1.20141028.9.mga7
+ Revision: 1316078
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 1:0.7.0-1.20141028.8.mga7
+ Revision: 1184652
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1:0.7.0-1.20141028.7.mga7
+ Revision: 1178070
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1:0.7.0-1.20141028.6.mga7
+ Revision: 1154674
- rebuild with latest boost

* Sat Dec 26 2015 daviddavid <daviddavid> 1:0.7.0-1.20141028.5.mga6
+ Revision: 915153
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 1:0.7.0-1.20141028.4.mga6
+ Revision: 883651
- rebuild for new boost 1.59.0

* Thu Sep 03 2015 cjw <cjw> 1:0.7.0-1.20141028.3.mga6
+ Revision: 872424
- rebuild with gcc 5

* Fri Jul 31 2015 daviddavid <daviddavid> 1:0.7.0-1.20141028.2.mga6
+ Revision: 859862
- rebuild for new boost-1.58.0

* Fri Mar 13 2015 akien <akien> 1:0.7.0-1.20141028.1.mga5
+ Revision: 818479
- imported package bear

